pub struct ClusterInfo {
pub mode: Option<String>,
pub domain: Option<Vec<String>>,
pub region: Option<String>,
pub deployment_id: Option<String>,
pub buckets: Option<BucketsInfo>,
pub objects: Option<ObjectsInfo>,
pub usage: Option<UsageInfo>,
pub backend: Option<BackendInfo>,
pub servers: Option<Vec<ServerInfo>>,
}Expand description
Complete cluster information response
Fields
mode: Option<String>Deployment mode (distributed, standalone)
domain: Option<Vec<String>>Domain names
region: Option<String>Region
deployment_id: Option<String>Deployment ID
buckets: Option<BucketsInfo>Bucket information
objects: Option<ObjectsInfo>Object information
usage: Option<UsageInfo>Storage usage
backend: Option<BackendInfo>Backend information
servers: Option<Vec<ServerInfo>>Server information
Implementations
Sourceimpl ClusterInfo
impl ClusterInfo
Sourcepub fn online_disks(&self) -> usize
pub fn online_disks(&self) -> usize
Get the total number of online disks across all servers
Sourcepub fn offline_disks(&self) -> usize
pub fn offline_disks(&self) -> usize
Get the total number of offline disks across all servers
Sourcepub fn total_capacity(&self) -> u64
pub fn total_capacity(&self) -> u64
Get total storage capacity in bytes
Sourcepub fn used_capacity(&self) -> u64
pub fn used_capacity(&self) -> u64
Get used storage in bytes