pub struct IamArchiveImportSection {
pub name: String,
pub policies: Vec<String>,
}Expand description
A failed IAM entity. Error text is intentionally discarded at the client boundary because a backend error may include credential material.
Fields
name: Stringpolicies: Vec<String>Trait Implementations
Sourceimpl Clone for IamArchiveImportSection
impl Clone for IamArchiveImportSection
Sourcefn clone(&self) -> IamArchiveImportSection
fn clone(&self) -> IamArchiveImportSection
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for IamArchiveImportSection
impl Debug for IamArchiveImportSection
Sourceimpl Default for IamArchiveImportSection
impl Default for IamArchiveImportSection
Sourcefn default() -> IamArchiveImportSection
fn default() -> IamArchiveImportSection
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for IamArchiveImportSection
impl<'de> Deserialize<'de> for IamArchiveImportSection
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for IamArchiveImportSection
Sourceimpl PartialEq for IamArchiveImportSection
impl PartialEq for IamArchiveImportSection
Sourceimpl Serialize for IamArchiveImportSection
impl Serialize for IamArchiveImportSection
impl StructuralPartialEq for IamArchiveImportSection