pub struct SourceCredentialsRequest {
pub access_key: String,
pub secret_key: Zeroizing<String>,
pub session_token: Option<Zeroizing<String>>,
}Expand description
Static credentials for the source, with the secret in zeroizing storage.
Debug never prints the secret or the session token.
Fields
access_key: Stringsecret_key: Zeroizing<String>session_token: Option<Zeroizing<String>>Trait Implementations
Sourceimpl Clone for SourceCredentialsRequest
impl Clone for SourceCredentialsRequest
Sourcefn clone(&self) -> SourceCredentialsRequest
fn clone(&self) -> SourceCredentialsRequest
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SourceCredentialsRequest
impl Debug for SourceCredentialsRequest