Module error

Module error 

Error types for rc-core

Provides a unified error type that can be converted to appropriate exit codes.

Enums

Error
Error types for rc-core operations
MultipartAbortStatus
Outcome of cleaning up a multipart upload after a copy failure.

Type Aliases

Result
Result type alias for rc-core operations