pub enum Error {
Show 20 variants
Config(String),
InvalidPath(String),
AliasNotFound(String),
AliasExists(String),
Io(Error),
TomlParse(Error),
TomlSerialize(Error),
Json(Error),
InvalidUrl(ParseError),
Auth(String),
NotFound(String),
VersionNotFound {
path: String,
version_id: String,
},
DeleteMarker {
path: String,
version_id: String,
},
GovernanceDenied {
path: String,
version_id: Option<String>,
},
Network(String),
Conflict(String),
UnsupportedFeature(String),
General(String),
RequestRejected(String),
Interrupted(String),
}Expand description
Error types for rc-core operations
Variants
Config(String)
Configuration file error
InvalidPath(String)
Invalid path format
AliasNotFound(String)
Alias not found
AliasExists(String)
Alias already exists
Io(Error)
IO error
TomlParse(Error)
TOML parsing error
TomlSerialize(Error)
TOML serialization error
Json(Error)
JSON error
InvalidUrl(ParseError)
URL parsing error
Auth(String)
Authentication error
NotFound(String)
Resource not found
VersionNotFound
A requested historical object version does not exist.
DeleteMarker
A read or metadata request selected a delete marker instead of object data.
GovernanceDenied
Object Lock governance retention rejected a delete request.
Fields
Network(String)
Network error (retryable)
Conflict(String)
Conflict error
UnsupportedFeature(String)
Feature not supported by backend
General(String)
General error
RequestRejected(String)
Request rejected locally before any network operation was attempted
Interrupted(String)
Operation stopped through an explicit cooperative cancellation request.
Implementations
Sourceimpl Error
impl Error
Sourcepub fn with_multipart_copy_context(
self,
upload_id: &str,
abort_status: MultipartAbortStatus,
) -> Self
pub fn with_multipart_copy_context( self, upload_id: &str, abort_status: MultipartAbortStatus, ) -> Self
Add multipart cleanup diagnostics without changing the primary error class.