Module object_lock

Module object_lock 

Typed Object Lock, retention, and legal-hold models.

Structs

BucketObjectLockConfiguration
Bucket Object Lock configuration.
DefaultRetention
Default retention rule applied to newly created object versions.
ObjectLockOptions
Version selection and protected-mutation options for Object Lock operations.
ObjectRetention
Retention applied to one object version.
RetentionDuration
Positive and unambiguous bucket default retention duration.

Enums

LegalHoldStatus
Legal-hold status applied to one object version.
RetentionDurationUnit
Unit used by a bucket’s default retention rule.
RetentionMode
Retention mode enforced by an Object Lock enabled bucket.