Path parsing and resolution
Handles parsing of remote paths in the format: alias/bucket[/key] Local paths are passed through as-is.
Structs
- Remote
Path - A parsed remote path pointing to an S3 location
Enums
- Parsed
Path - Parsed path that can be either local or remote
Functions
- parse_
object_ path - Parse a remote path that must refer to a single object (
alias/bucket/keywith non-empty key). - parse_
path - Parse a path string into a ParsedPath