pub enum ParsedPath {
Local(PathBuf),
Remote(RemotePath),
}Expand description
Parsed path that can be either local or remote
Variants
Implementations
Sourceimpl ParsedPath
impl ParsedPath
Sourcepub fn as_remote(&self) -> Option<&RemotePath>
pub fn as_remote(&self) -> Option<&RemotePath>
Get the remote path if this is a remote path