pub fn parse_object_path(path: &str) -> Result<RemotePath>Expand description
Parse a remote path that must refer to a single object (alias/bucket/key with non-empty key).
pub fn parse_object_path(path: &str) -> Result<RemotePath>Parse a remote path that must refer to a single object (alias/bucket/key with non-empty key).