pub struct ObjectReadOptions {
pub version_id: Option<String>,
}Expand description
Options for selecting an object version during read and metadata operations.
Fields
version_id: Option<String>Exact object version to select. None selects the current object.
Implementations
Sourceimpl ObjectReadOptions
impl ObjectReadOptions
Sourcepub fn for_version(version_id: Option<String>) -> Result<Self>
pub fn for_version(version_id: Option<String>) -> Result<Self>
Build read options while rejecting ambiguous empty version identifiers.