pub struct TransferExecutor { /* private fields */ }Expand description
Executes a transfer plan with shared controls.
Implementations
Sourceimpl TransferExecutor
impl TransferExecutor
pub fn new(controls: TransferControls) -> Result<Self>
Sourcepub async fn execute<T, F, Fut>(
&self,
plan: TransferPlan<T>,
operation: F,
) -> TransferReport<T>
pub async fn execute<T, F, Fut>( &self, plan: TransferPlan<T>, operation: F, ) -> TransferReport<T>
Execute candidates while bounding all in-flight work across the command.
Sourcepub async fn execute_with_cancellation<T, F, Fut>(
&self,
plan: TransferPlan<T>,
cancellation: TransferCancellation,
operation: F,
) -> TransferReport<T>
pub async fn execute_with_cancellation<T, F, Fut>( &self, plan: TransferPlan<T>, cancellation: TransferCancellation, operation: F, ) -> TransferReport<T>
Execute candidates until completion, failure policy, or cooperative cancellation.
Work already in flight is allowed to settle so callers can await backend cleanup.