rc-core: Core library for the rc S3 CLI client
This crate provides the core functionality for the rc CLI, including:
- Configuration management
- Alias management
- Path parsing and resolution
- ObjectStore trait for S3 operations
This crate is designed to be independent of any specific S3 SDK, allowing for easy testing and potential future support for other backends.
Re-exports
pub use alias::Alias;pub use alias::AliasManager;pub use config::Config;pub use config::ConfigManager;pub use error::Error;pub use error::Result;pub use path::ParsedPath;pub use path::RemotePath;pub use path::parse_path;pub use retry::RetryBuilder;pub use retry::is_retryable_error;pub use retry::retry_with_backoff;pub use traits::Capabilities;pub use traits::ListOptions;pub use traits::ListResult;pub use traits::ObjectInfo;pub use traits::ObjectStore;pub use traits::ObjectVersion;