Module admin

Module admin 

Admin API module

This module provides the AdminApi trait and types for managing IAM users, policies, groups, service accounts, and cluster operations.

Structs

BackendInfo
Backend information
BucketQuota
Bucket quota information returned by Admin API
BucketsInfo
Bucket count information
ClusterInfo
Complete cluster information response
CreateServiceAccountRequest
Request to create a service account
DiskInfo
Disk information
Group
Represents an IAM group
HealDriveInfo
Information about a single heal drive
HealDriveInfos
Collection of heal drive infos
HealResultItem
Result of a heal operation on a single item
HealStartRequest
Request to start a heal operation
HealStatus
Status of a heal operation
HealingDiskInfo
Healing disk information
MemStats
Memory statistics
ObjectsInfo
Object count information
Policy
Represents an IAM policy
PolicyInfo
Summary information about a policy (without the full document)
ServerInfo
Server information representing a RustFS node
ServiceAccount
Represents a service account (access key pair)
ServiceAccountCreateResponse
ServiceAccountCredentials
SetPolicyRequest
Request to set/attach policies
UpdateGroupMembersRequest
Request to update group members
UsageInfo
Cluster usage statistics
User
Represents an IAM user

Enums

BackendType
Storage backend type
GroupStatus
Group status indicating whether the group is enabled or disabled
HealScanMode
Heal operation mode
PolicyEntity
Entity type for policy attachment
UserStatus
User status indicating whether the user is enabled or disabled

Traits

AdminApi
Admin API trait for IAM and cluster management operations