Admin API module
This module provides the AdminApi trait and types for managing IAM users, policies, groups, service accounts, and cluster operations.
Structs
- Backend
Info - Backend information
- Bucket
Quota - Bucket quota information returned by Admin API
- Buckets
Info - Bucket count information
- Cluster
Info - Complete cluster information response
- Create
Service Account Request - Request to create a service account
- Disk
Info - Disk information
- Group
- Represents an IAM group
- Heal
Drive Info - Information about a single heal drive
- Heal
Drive Infos - Collection of heal drive infos
- Heal
Result Item - Result of a heal operation on a single item
- Heal
Start Request - Request to start a heal operation
- Heal
Status - Status of a heal operation
- Healing
Disk Info - Healing disk information
- MemStats
- Memory statistics
- Objects
Info - Object count information
- Policy
- Represents an IAM policy
- Policy
Info - Summary information about a policy (without the full document)
- Server
Info - Server information representing a RustFS node
- Service
Account - Represents a service account (access key pair)
- Service
Account Create Response - Service
Account Credentials - SetPolicy
Request - Request to set/attach policies
- Update
Group Members Request - Request to update group members
- Usage
Info - Cluster usage statistics
- User
- Represents an IAM user
Enums
- Backend
Type - Storage backend type
- Group
Status - Group status indicating whether the group is enabled or disabled
- Heal
Scan Mode - Heal operation mode
- Policy
Entity - Entity type for policy attachment
- User
Status - User status indicating whether the user is enabled or disabled
Traits
- Admin
Api - Admin API trait for IAM and cluster management operations