pub struct SiteReplicationResyncStatus {
pub operation: String,
pub resync_id: String,
pub status: String,
pub buckets: Vec<SiteReplicationResyncBucketStatus>,
pub error_detail: String,
pub extensions: BTreeMap<String, Value>,
/* private fields */
}Expand description
Typed response from site-replication/resync/op.
Fields
operation: Stringresync_id: Stringstatus: Stringbuckets: Vec<SiteReplicationResyncBucketStatus>error_detail: Stringextensions: BTreeMap<String, Value>Implementations
Sourceimpl SiteReplicationResyncStatus
impl SiteReplicationResyncStatus
Sourcepub fn capture_semantics(&mut self)
pub fn capture_semantics(&mut self)
Freeze protocol semantics before credentials are redacted for output.
Once captured, the semantic result intentionally remains stable even if the public wire fields are replaced by their safe output projections.
Sourcepub fn has_failure(&self) -> bool
pub fn has_failure(&self) -> bool
Detect overall and partial failures without trusting a success summary.
Sourcepub fn is_not_found(&self) -> bool
pub fn is_not_found(&self) -> bool
Detect the wire-level no-snapshot marker after output sanitization.