pub trait KmsDiagnosticStore: Send + Sync {
// Required methods
fn put_kms_diagnostic_object<'life0, 'life1, 'life2, 'async_trait>(
&'life0 self,
path: &'life1 RemotePath,
content: Zeroizing<Vec<u8>>,
key_id: &'life2 str,
) -> Pin<Box<dyn Future<Output = Result<()>> + Send + 'async_trait>>
where Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
'life2: 'async_trait;
fn get_kms_diagnostic_object<'life0, 'life1, 'async_trait>(
&'life0 self,
path: &'life1 RemotePath,
max_bytes: usize,
) -> Pin<Box<dyn Future<Output = Result<Zeroizing<Vec<u8>>>> + Send + 'async_trait>>
where Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait;
fn delete_kms_diagnostic_object<'life0, 'life1, 'async_trait>(
&'life0 self,
path: &'life1 RemotePath,
) -> Pin<Box<dyn Future<Output = Result<()>> + Send + 'async_trait>>
where Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait;
}Expand description
Adapter boundary for the three sensitive object operations used by the diagnostic.
Required Methods
Sourcefn put_kms_diagnostic_object<'life0, 'life1, 'life2, 'async_trait>(
&'life0 self,
path: &'life1 RemotePath,
content: Zeroizing<Vec<u8>>,
key_id: &'life2 str,
) -> Pin<Box<dyn Future<Output = Result<()>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
'life2: 'async_trait,
fn put_kms_diagnostic_object<'life0, 'life1, 'life2, 'async_trait>(
&'life0 self,
path: &'life1 RemotePath,
content: Zeroizing<Vec<u8>>,
key_id: &'life2 str,
) -> Pin<Box<dyn Future<Output = Result<()>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
'life2: 'async_trait,
Upload bounded plaintext with explicit SSE-KMS encryption.
Sourcefn get_kms_diagnostic_object<'life0, 'life1, 'async_trait>(
&'life0 self,
path: &'life1 RemotePath,
max_bytes: usize,
) -> Pin<Box<dyn Future<Output = Result<Zeroizing<Vec<u8>>>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
fn get_kms_diagnostic_object<'life0, 'life1, 'async_trait>(
&'life0 self,
path: &'life1 RemotePath,
max_bytes: usize,
) -> Pin<Box<dyn Future<Output = Result<Zeroizing<Vec<u8>>>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
Read and decrypt bounded diagnostic plaintext.
Sourcefn delete_kms_diagnostic_object<'life0, 'life1, 'async_trait>(
&'life0 self,
path: &'life1 RemotePath,
) -> Pin<Box<dyn Future<Output = Result<()>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
fn delete_kms_diagnostic_object<'life0, 'life1, 'async_trait>(
&'life0 self,
path: &'life1 RemotePath,
) -> Pin<Box<dyn Future<Output = Result<()>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
Permanently remove the temporary object, including from versioned buckets.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".