Typed Object Lock, retention, and legal-hold models.
Structs
- Bucket
Object Lock Configuration - Bucket Object Lock configuration.
- Default
Retention - Default retention rule applied to newly created object versions.
- Object
Lock Options - Version selection and protected-mutation options for Object Lock operations.
- Object
Retention - Retention applied to one object version.
- Retention
Duration - Positive and unambiguous bucket default retention duration.
Enums
- Legal
Hold Status - Legal-hold status applied to one object version.
- Retention
Duration Unit - Unit used by a bucket’s default retention rule.
- Retention
Mode - Retention mode enforced by an Object Lock enabled bucket.