Bucket replication configuration types
Domain types for S3 bucket replication configuration and RustFS admin API remote target management.
Structs
- Bucket
Target - Remote bucket target for replication (matches RustFS admin API JSON format)
- Bucket
Target Credentials - Credentials for a remote bucket target
- Replication
Check Phase - One phase of the server’s active target validation state machine.
- Replication
Check Phases - All phases reported for one configured replication target.
- Replication
Check Result - Result of the active replication-target validation extension.
- Replication
Check Target - Structured outcome for one configured replication target.
- Replication
Configuration - Full replication configuration for a bucket (S3 API)
- Replication
Destination - Replication destination
- Replication
Resync Start Options - Options for starting a RustFS bucket replication resync.
- Replication
Resync Start Result - A target accepted by a bucket replication resync start request.
- Replication
Resync Status - Current server-side bucket replication resync state.
- Replication
Resync Target Status - Status for one configured replication target.
- Replication
Rule - A single replication rule
Enums
- Replication
Check Phase State - Outcome of one phase in an active replication check.
- Replication
Check Status - Overall or per-target outcome of an active replication check.
- Replication
Resync State - Server state for a bucket replication resync target.
- Replication
Rule Status - Rule status