Backend-neutral options for faithful object reads, writes, and copies.
Structs
- Object
Attributes - Standard HTTP object attributes and user-defined metadata.
- Object
Checksum - An encoded checksum paired with its algorithm.
- Object
Transfer Metadata - Fidelity metadata returned independently of the stable ObjectInfo output contract.
- Object
Write Options - Complete destination options for an object write or copy.
- SseCustomer
Key - A 256-bit SSE-C key whose formatting never reveals key material.
- Transfer
Copy Options - Complete options for a faithful server-side object copy.
- Transfer
Read Options - Advanced read options that do not change the legacy ObjectReadOptions contract.
Enums
- Checksum
Algorithm - Checksum algorithms understood by S3-compatible object APIs.
- Checksum
Request - How a destination checksum should be supplied.
- Metadata
Directive - How CopyObject handles source metadata.
- Object
Write Encryption - Encryption requested for a destination object.
- Tagging
Directive - How CopyObject handles source tags.